@@ -26,6 +26,7 @@ from tkinter import filedialog
 from simublocks.element import Workspace, Block
 from simublocks.dialog import Dialog
 import simublocks.examples as ex
+import copy
 
 class FileApp:
     def save():
@@ -65,10 +66,14 @@ class FileApp:
         FileApp.new()
         if name == 'openloop':
             FileApp.createProject( ex.openloop )
-        if name == 'closedloop':
+        elif name == 'closedloop':
             FileApp.createProject( ex.closedloop )
+        elif name == 'noise':
+            FileApp.createProject( ex.noise_example )
 
-    def createProject(project):
+
+    def createProject(_dict):
+        project = copy.deepcopy(_dict)
         blocks = {}
         # Create each block
         for i in project['blocks']:
